yt.data\_objects.index\_subobjects package
==========================================

Submodules
----------

.. toctree::
   :maxdepth: 4

   yt.data_objects.index_subobjects.grid_patch
   yt.data_objects.index_subobjects.octree_subset
   yt.data_objects.index_subobjects.particle_container
   yt.data_objects.index_subobjects.unstructured_mesh

Module contents
---------------

.. automodule:: yt.data_objects.index_subobjects
   :members:
   :undoc-members:
   :inherited-members:
   :show-inheritance:
